module.exports={A:{A:{"388":"A B","900":"K D E F wC"},B:{"388":"C L M G N O P","641":"0 1 2 3 4 5 r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB","900":"Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},C:{"772":"0 1 2 3 4 5 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC","900":"6 7 8 9 xC UC J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 0C 1C"},D:{"641":"0 1 2 3 4 5 r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC","900":"6 7 8 9 J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q"},E:{"772":"A","900":"J aB K D E F B C L M G 2C aC 3C 4C 5C 6C bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD"},F:{"16":"F GD","129":"B C HD ID JD OC uC KD PC","641":"0 1 2 3 4 5 d e f g h i j k l m n o p q r s t u v w x y z","900":"6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c"},G:{"900":"E aC LD vC MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC"},H:{"129":"jD"},I:{"641":"I","900":"UC J kD lD mD nD vC oD pD"},J:{"900":"D A"},K:{"129":"A B C OC uC PC","641":"H"},L:{"900":"I"},M:{"772":"NC"},N:{"388":"A B"},O:{"900":"QC"},P:{"641":"7 8 9 AB BB CB DB EB FB","900":"6 J qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"900":"1D"},R:{"900":"2D"},S:{"772":"4D","900":"3D"}},B:2,C:"CSS page-break properties",D:true};
