module.exports={A:{A:{"2":"K D E F wC","129":"A B"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB","129":"C L","1025":"M G N O P"},C:{"2":"6 7 8 9 xC UC J aB K D E F A B C L M G N O P bB AB BB CB DB EB 0C 1C","513":"0 1 2 3 4 5 FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC","2":"J aB"},E:{"1":"aB K D E F A B C L M G 3C 4C 5C 6C bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD","2":"J 2C aC"},F:{"1":"0 1 2 3 4 5 6 7 8 9 F B C G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GD HD ID JD OC uC KD PC"},G:{"388":"E aC LD vC MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC"},H:{"2":"jD"},I:{"2":"UC kD lD mD","388":"J I nD vC oD pD"},J:{"2":"D","388":"A"},K:{"1":"A B C OC uC PC","388":"H"},L:{"388":"I"},M:{"641":"NC"},N:{"388":"A B"},O:{"388":"QC"},P:{"388":"6 7 8 9 J AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"388":"1D"},R:{"388":"2D"},S:{"513":"3D 4D"}},B:1,C:"Number input type",D:true};
