module.exports={A:{A:{"1":"A B","2":"K D E F wC"},B:{"1":"C L M G N O P","516":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB"},C:{"132":"yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B","164":"6 7 8 9 xC UC J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB 0C 1C","516":"9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a","1028":"0 1 2 3 4 5 b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC"},D:{"420":"6 7 8 9 J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB","516":"0 1 2 3 4 5 wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC"},E:{"1":"A B C L M G bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD","132":"F 6C","164":"D E 5C","420":"J aB K 2C aC 3C 4C"},F:{"1":"C OC uC KD PC","2":"F B GD HD ID JD","420":"6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB","516":"0 1 2 3 4 5 jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"1":"SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC","132":"QD RD","164":"E OD PD","420":"aC LD vC MD ND"},H:{"1":"jD"},I:{"420":"UC J kD lD mD nD vC oD pD","516":"I"},J:{"420":"D A"},K:{"1":"C OC uC PC","2":"A B","516":"H"},L:{"516":"I"},M:{"1028":"NC"},N:{"1":"A B"},O:{"516":"QC"},P:{"420":"J","516":"6 7 8 9 AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"516":"1D"},R:{"516":"2D"},S:{"164":"3D 4D"}},B:4,C:"CSS3 Multiple column layout",D:true};
