module.exports={A:{A:{"1":"B","2":"K D E F A wC"},B:{"1":"0 1 2 3 4 5 M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB","129":"C L"},C:{"1":"0 1 2 3 4 5 wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC","2":"xC UC","260":"6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB","804":"J aB K D E F A B C L M 0C 1C"},D:{"1":"0 1 2 3 4 5 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC","260":"xB yB zB 0B 1B","388":"cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB","1412":"6 7 8 9 G N O P bB AB BB CB DB EB FB","1956":"J aB K D E F A B C L M"},E:{"1":"dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD","129":"A B C L M G 6C bC OC PC 7C 8C 9C cC","1412":"K D E F 4C 5C","1956":"J aB 2C aC 3C"},F:{"1":"0 1 2 3 4 5 pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z","2":"F GD HD","260":"kB lB mB nB oB","388":"6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB","1796":"ID JD","1828":"B C OC uC KD PC"},G:{"1":"dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC","129":"RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC","1412":"E ND OD PD QD","1956":"aC LD vC MD"},H:{"1828":"jD"},I:{"1":"I","388":"oD pD","1956":"UC J kD lD mD nD vC"},J:{"1412":"A","1924":"D"},K:{"1":"H","2":"A","1828":"B C OC uC PC"},L:{"1":"I"},M:{"1":"NC"},N:{"1":"B","2":"A"},O:{"1":"QC"},P:{"1":"6 7 8 9 AB BB CB DB EB FB sD tD uD bC vD wD xD yD zD RC SC TC 0D","260":"qD rD","388":"J"},Q:{"1":"1D"},R:{"1":"2D"},S:{"1":"4D","260":"3D"}},B:4,C:"CSS3 Border images",D:true};
