module.exports={A:{A:{"2":"K D E F A B wC"},B:{"1":"0 1 2 3 4 5 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB","2":"C L M G N"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC 0C 1C","2":"xC UC"},D:{"1":"0 1 2 3 4 5 6 7 8 9 J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC"},E:{"1":"rC DD sC tC ED FD","2":"J aB K D E F A B C L M 2C aC 3C 4C 5C 6C bC OC PC 7C","260":"SC jC kC lC mC nC CD TC oC pC qC","388":"G 8C 9C cC dC QC AD RC eC fC gC hC iC BD"},F:{"1":"0 1 2 3 4 5 6 7 8 9 B C G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z ID JD OC uC KD PC","2":"F GD HD"},G:{"1":"rC iD sC tC","2":"E aC LD vC MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC","260":"mC nC hD TC oC pC qC"},H:{"2":"jD"},I:{"1":"UC J I mD nD vC oD pD","16":"kD lD"},J:{"1":"A","2":"D"},K:{"1":"B C H OC uC PC","2":"A"},L:{"1":"I"},M:{"1":"NC"},N:{"2":"A B"},O:{"1":"QC"},P:{"1":"6 7 8 9 J AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"1":"1D"},R:{"1":"2D"},S:{"1":"3D 4D"}},B:6,C:"Ogg Vorbis audio format",D:true};
