module.exports={A:{A:{"2":"K D E wC","260":"F A B"},B:{"2":"UB VB WB XB YB I ZB","66":"KB LB MB NB OB PB QB RB SB TB","132":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB","260":"C L M G N O P"},C:{"2":"xC UC J aB XB YB I ZB NC YC ZC yC zC 0C 1C","260":"0 1 2 3 4 5 6 7 8 9 K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB"},D:{"2":"SB TB UB VB WB XB YB I ZB NC YC ZC","16":"J aB K D E F A B C L M","66":"KB LB MB NB OB PB QB RB","132":"0 1 2 3 4 5 6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB"},E:{"2":"sC tC ED FD","16":"2C aC","132":"J aB K D E F A B C L M G 3C 4C 5C 6C bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD"},F:{"1":"C KD PC","2":"F GD HD ID JD","16":"B OC uC","66":"0 1 2 3 4 5 w x y z","132":"6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v"},G:{"2":"sC tC","16":"aC LD","132":"E vC MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD"},H:{"2":"jD"},I:{"2":"I","16":"kD lD","132":"UC J mD nD vC oD pD"},J:{"132":"D A"},K:{"1":"C PC","2":"A","16":"B OC uC","132":"H"},L:{"2":"I"},M:{"2":"NC"},N:{"260":"A B"},O:{"132":"QC"},P:{"132":"6 7 8 9 J AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"132":"1D"},R:{"132":"2D"},S:{"260":"3D 4D"}},B:7,C:"Mutation events",D:true};
