module.exports={A:{A:{"2":"F A B wC","8":"K D E"},B:{"2":"C L M G N O P","8":"Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC","129":"xC UC 0C 1C"},D:{"1":"AB","8":"6 7 8 9 J aB K D E F A B C L M G N O P bB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f","584":"g h i j k l m n o p q r","1025":"0 1 2 3 4 5 s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC"},E:{"1":"A B C L M G bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD","260":"J aB K D E F 2C aC 3C 4C 5C 6C"},F:{"2":"F","8":"6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC","584":"S T U V W X Y Z a b c d","1025":"0 1 2 3 4 5 e f g h i j k l m n o p q r s t u v w x y z","2052":"B C GD HD ID JD OC uC KD PC"},G:{"1":"E MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC","8":"aC LD vC"},H:{"8":"jD"},I:{"8":"UC J kD lD mD nD vC oD pD","1025":"I"},J:{"1":"A","8":"D"},K:{"8":"A B C OC uC PC","1025":"H"},L:{"1025":"I"},M:{"1":"NC"},N:{"2":"A B"},O:{"8":"QC"},P:{"1":"7 8 9 AB BB CB DB EB FB","8":"6 J qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"8":"1D"},R:{"8":"2D"},S:{"1":"3D 4D"}},B:2,C:"MathML",D:true};
