import 'std-env';

var _a;
const isNode = typeof process < "u" && typeof process.stdout < "u" && !((_a = process.versions) == null ? void 0 : _a.deno) && !globalThis.window;
const isWindows = isNode && process.platform === "win32";

export { isWindows as a, isNode as i };
