export { V as VitestExecutor } from './vendor/execute.fL3szUAI.js';
import 'node:vm';
import 'node:url';
import 'node:fs';
import 'vite-node/client';
import 'vite-node/utils';
import 'pathe';
import '@vitest/utils/error';
import './path.js';
import '@vitest/utils';
import './vendor/base.5NT-gWu5.js';
