import * as _vitest_utils_source_map from '@vitest/utils/source-map';
export * from '@vitest/utils';

declare function loadSourceMapUtils(): Promise<typeof _vitest_utils_source_map>;

export { loadSourceMapUtils };
