module.exports={A:{A:{"132":"K D E F A B wC"},B:{"1":"0 1 2 3 4 5 Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB","132":"C L M G N O P"},C:{"1":"0 1 2 3 4 5 wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC","33":"6 7 8 9 O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB","132":"xC UC J aB K D E F 0C 1C","292":"A B C L M G N"},D:{"1":"0 1 2 3 4 5 uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC","132":"J aB K D E F A B C L M G N","548":"6 7 8 9 O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB"},E:{"132":"J aB K D E 2C aC 3C 4C 5C","548":"F A B C L M G 6C bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD"},F:{"132":"0 1 2 3 4 5 6 7 8 9 F B C G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GD HD ID JD OC uC KD PC"},G:{"132":"E aC LD vC MD ND OD PD","548":"QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC"},H:{"16":"jD"},I:{"1":"I","16":"UC J kD lD mD nD vC oD pD"},J:{"16":"D A"},K:{"1":"H","16":"A B C OC uC PC"},L:{"1":"I"},M:{"1":"NC"},N:{"132":"A B"},O:{"1":"QC"},P:{"1":"6 7 8 9 AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D","16":"J"},Q:{"1":"1D"},R:{"1":"2D"},S:{"1":"4D","33":"3D"}},B:4,C:"CSS unicode-bidi property",D:false};
