declare function normalizeAliases(_aliases: Record<string, string>): Record<string, string>;
declare function resolveAlias(path: string, aliases: Record<string, string>): string;
declare function filename(path: string): string;

export { filename, normalizeAliases, resolveAlias };
