'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./shared/pathe.1f0a373c.cjs');



exports.basename = index.basename;
exports.default = index.path;
exports.delimiter = index.delimiter;
exports.dirname = index.dirname;
exports.extname = index.extname;
exports.format = index.format;
exports.isAbsolute = index.isAbsolute;
exports.join = index.join;
exports.normalize = index.normalize;
exports.normalizeString = index.normalizeString;
exports.parse = index.parse;
exports.relative = index.relative;
exports.resolve = index.resolve;
exports.sep = index.sep;
exports.toNamespacedPath = index.toNamespacedPath;
