module.exports={A:{A:{"2":"K D E wC","260":"F A B"},B:{"1":"0 1 2 3 4 5 C L M G N O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB"},C:{"1":"0 1 2 3 4 5 6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC","2":"xC UC J aB K D E F A B C L M 0C 1C"},D:{"1":"0 1 2 3 4 5 wB xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC","2":"6 7 8 9 J aB K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB","132":"iB jB kB lB mB nB oB pB qB rB sB tB uB vB"},E:{"1":"C L M G OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD","2":"J aB K D F A B 2C aC 3C 4C 6C bC","132":"E 5C"},F:{"1":"0 1 2 3 4 5 jB kB lB mB nB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z PC","2":"6 7 8 G N O P bB","4":"B C HD ID JD OC uC KD","16":"F GD","132":"9 AB BB CB DB EB FB cB dB eB fB gB hB iB"},G:{"1":"VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC","2":"aC LD vC MD ND OD QD RD SD TD UD","132":"E PD"},H:{"1":"jD"},I:{"1":"I","2":"UC J kD lD mD nD vC oD pD"},J:{"2":"D","132":"A"},K:{"1":"H PC","4":"A B C OC uC"},L:{"1":"I"},M:{"1":"NC"},N:{"1":"A B"},O:{"1":"QC"},P:{"1":"6 7 8 9 AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D","132":"J"},Q:{"1":"1D"},R:{"1":"2D"},S:{"1":"3D 4D"}},B:4,C:"SVG fragment identifiers",D:true};
