module.exports={A:{A:{"1":"B","4":"K D E F A wC"},B:{"1":"C L M G N","129":"0 1 2 3 4 5 O P Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB"},C:{"1":"6 7 8 9 K D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB rB sB tB uB vB wB","4":"xC UC J aB 0C 1C","129":"0 1 2 3 4 5 xB yB zB 0B 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC yC zC"},D:{"1":"rB sB tB uB vB wB xB yB zB 0B","4":"J aB K","129":"0 1 2 3 4 5 6 7 8 9 D E F A B C L M G N O P bB AB BB CB DB EB FB cB dB eB fB gB hB iB jB kB lB mB nB oB pB qB 1B 2B 3B 4B VC 5B WC 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z GB HB IB JB KB LB MB NB OB PB QB RB SB TB UB VB WB XB YB I ZB NC YC ZC"},E:{"4":"J aB 2C aC","129":"K D E F A B C L M G 3C 4C 5C 6C bC OC PC 7C 8C 9C cC dC QC AD RC eC fC gC hC iC BD SC jC kC lC mC nC CD TC oC pC qC rC DD sC tC ED FD"},F:{"1":"C eB fB gB hB iB jB kB lB mB nB OC uC KD PC","4":"F B GD HD ID JD","129":"0 1 2 3 4 5 6 7 8 9 G N O P bB AB BB CB DB EB FB cB dB oB pB qB rB sB tB uB vB wB xB yB zB 0B 1B 2B 3B 4B 5B 6B 7B 8B 9B AC BC CC DC EC FC GC HC IC JC KC LC MC Q H R XC S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z"},G:{"4":"aC LD vC","129":"E MD ND OD PD QD RD SD TD UD VD WD XD YD ZD aD bD cD dD eD cC dC QC fD RC eC fC gC hC iC gD SC jC kC lC mC nC hD TC oC pC qC rC iD sC tC"},H:{"4":"jD"},I:{"4":"kD lD mD","129":"UC J I nD vC oD pD"},J:{"129":"D A"},K:{"1":"C OC uC PC","4":"A B","129":"H"},L:{"129":"I"},M:{"129":"NC"},N:{"1":"B","4":"A"},O:{"129":"QC"},P:{"129":"6 7 8 9 J AB BB CB DB EB FB qD rD sD tD uD bC vD wD xD yD zD RC SC TC 0D"},Q:{"129":"1D"},R:{"129":"2D"},S:{"1":"3D","129":"4D"}},B:1,C:"dataset & data-* attributes",D:true};
